@@ -27,14 +27,9 @@ Implementation Notes
   https://github.com/adafruit/Adafruit_CircuitPython_BusDevice
 
 """
-
+import struct
 import time
 
-try:
-    import struct
-except ImportError:
-    import ustruct as struct
-
 from micropython import const
 
 __version__ = "0.0.0-auto.0"
